@@ -1,9 +1,10 @@
-
 from .complete import CompleteBackupGroup, complete_groups_from_dict
 from .pending import BackupGroup, groups_from_dict
 
 
 __all__ = [
-    "CompleteBackupGroup", "BackupGroup", "complete_groups_from_dict",
-    "groups_from_dict"
+    "CompleteBackupGroup",
+    "BackupGroup",
+    "complete_groups_from_dict",
+    "groups_from_dict",
 ]
